@@ -1,21 +1,18 @@
-plot.mfp <- function (x, var=NULL, ...) 
+plot.mfp <- function (x, var=NULL, ref.zero=TRUE, ...) 
 {
     if (!inherits(x, "mfp")) 
         stop("This is not an mfp object")
     name <- dimnames(x$powers)[[1]]
     choices <- name
     if(is.null(var)) {
-      pick <- seq(name)[-which(is.na(x$powers[,1]))]
-    } else { pick <- which(name %in% var) }
+      w <- which(is.na(x$powers[,1]))
+      if(length(w)==0) { pick <- seq(name) } 
+      else { pick <- seq(name)[-w] }
+    } else { 
+      pick <- which(name %in% var)
+    }
     int <- as.numeric(x$family[["family"]] != "Cox")
     for(ip in pick) {
-        npwrsx <- sum(!is.na(x$powers[ip, ]))
-        if (npwrsx > 0) {
-            if (ip > 1) 
-                posx <- int + sum(!is.na(x$powers[seq(ip-1), ])) + seq(npwrsx)
-            else posx <- int + seq(npwrsx)
-            fx <- x$x[, posx, drop = FALSE] %*% x$coef[posx]
-        }
         namex <- name[ip]
         if (is.null(x$X)) 
             stop("you did not specify x=T in the fit")
@@ -27,32 +24,51 @@ plot.mfp <- function (x, var=NULL, ...)
             tmpx <- eval(as.name(namex))
         }
         ord <- order(tmpx)
-        if (int) {
+    	tmpx <- sort(tmpx)
+#
+        npwrsx <- sum(!is.na(x$powers[ip, ]))
+        if (npwrsx > 0) {
+            if (ip > 1) 
+                posx <- int + sum(!is.na(x$powers[seq(ip-1), ])) + seq(npwrsx)
+            else posx <- int + seq(npwrsx)
+			xtmp <- t(matrix(tmpx,ncol=length(tmpx),nrow=npwrsx,byrow=T)^x$powers[ip,1:npwrsx])
+            fx <- xtmp %*% x$coef[posx]
+            if (ref.zero) {
+             xcenter <- mean(tmpx, na.rm=T)^x$powers[ip,1:npwrsx]
+             ycenter <- as.vector(xcenter %*% x$coef[posx])
+             fx <- fx - ycenter
+            }
+        }
+
+# Plots
+        if (int) {                      # generalized linear model
             if (npwrsx > 0) {
-                plot(tmpx[ord], fx[ord], xlab = namex, ylab = paste("Linear predictor", 
+                plot(tmpx, fx, xlab = namex, ylab = paste("Linear predictor", 
                   sep = ""), type = "l", ...)
-                pres <- x$residuals + fx
+                pres <- x$residuals[ord] + fx
                 plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", 
                   ...)
-                fl <- lowess(tmpx[ord], pres[ord], iter = 0)
+                fl <- lowess(tmpx, pres, iter = 0)
                 lines(fl$x, fl$y, lwd = 1, col = "red")
             }
         }
-        else {
+        else {                          # Cox proportional hazards model
             require(survival)
+# Martingale residuals
             x0 <- coxph(x$y ~ 1)
             res0 <- resid(x0, type = "mart")
             plot(tmpx, res0, xlab = namex, ylab = "Martingale residuals", 
                 type = "p", ...)
-            fl <- lowess(tmpx[ord], res0[ord], iter = 0)
+            fl <- lowess(tmpx, res0[ord], iter = 0)
             lines(fl$x, fl$y, lwd = 1, col = "red")
+# Fitted function
             if (npwrsx > 0) {
-                plot(tmpx[ord], fx[ord], xlab = namex, ylab = "Linear predictor", 
+                plot(tmpx, fx, xlab = namex, ylab = "Linear predictor", 
                   type = "l", ...)
-                pres <- x$residuals + fx
+                pres <- x$residuals[ord] + fx
                 plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", 
                   ...)
-                fl <- lowess(tmpx[ord], pres[ord], iter = 0)
+                fl <- lowess(tmpx, pres, iter = 0)
                 lines(fl$x, fl$y, lwd = 1, col = "red")
             }
         }
